## S3 method for class 'kcca':
barplot(height, bycluster = TRUE, oneplot = TRUE,
data = NULL, FUN=colMeans, main = deparse(substitute(height)),
which = 1:height@k, names.arg = NULL,
oma=par("oma"), col=NULL, mcol="darkred", srt=45, ...)## S3 method for class 'kcca':
barchart(x, data, xlab="", strip.prefix="Cluster ",
col=NULL, mcol="darkred", panel=NULL, which=NULL, ...)
"kcca".TRUE, then each barplot shows one
cluster. If FALSE, then each barplot compares all cluster for
one input variable.TRUE, all barplots are plotted together on
one page, else each plot is on a seperate page.NULL, cluster membership is predicted for
the new data and used for the plots. By default the
values from the training data are used. Ignored by the barchart
method.barplot index number of clusters for the plot,
for barchart index numbers or names of variables to plot.NULL, the value of
FUN for the complete data set is plotted over each bar as a
line segment with color mcol.barchart.